import React, { ChangeEvent, FormEvent, FunctionComponent, ReactElement, useState } from "react";
import { shallowEqual, useDispatch, useSelector } from "react-redux";
import IProductDto from "../../interfaces/IProductDto";
import IUserCreateDto from "../../interfaces/IUserCreateDto";
import { createProduct } from "../../store/products/products.slice";
import { AppDispatch, AppState } from "../../store/store";
import { editUser, sendEmailPassword } from "../../store/users/users.slice";
import styles from './ForgotPasswordForm.module.css'

const ForgotPasswordForm: FunctionComponent = (): ReactElement => {
    const dispatch: AppDispatch = useDispatch()
    const [errorMessage, setErrorMessage] = useState<string>('')
    const [email, setEmail] = useState<string>('')
    const inputHandler = (e: ChangeEvent<HTMLInputElement>): void => {
        setEmail(e.target.value)
    }
    const submitHandler = (e: FormEvent) => {
        e.preventDefault()

        dispatch(sendEmailPassword(email))
    }
    return (
        <div className={styles.ForgotPasswordForm__frame}>
            <form className={styles.ForgotPasswordForm} onSubmit={submitHandler}>
                <h6>{errorMessage}</h6>
                <input 
                    name={'Email'} 
                    type="email" 
                    placeholder="Email" 
                    value={email}
                    onChange={inputHandler}
                    className={styles.ForgotPasswordForm__input}
                />
                <button className={styles.ForgotPasswordForm__button}>SEND</button>
            </form>
        </div>
    )
}

export default ForgotPasswordForm