import React, { createContext, useEffect } from 'react'
import { shallowEqual, useDispatch, useSelector } from 'react-redux'
import { Navigate, Outlet, useLocation } from 'react-router-dom'
import { AppDispatch, AppState } from '../store/store'
import { checkToken } from '../store/users/users.slice'
import { ERoles } from '../enums/ERoles'

export const UserContext = createContext<ERoles | undefined>(undefined)
const PrivateRoute: React.FunctionComponent = (): React.ReactElement => {
    const {isAuth, user} = useSelector((state: AppState) => state.users, shallowEqual)
    const location = useLocation()
    const dispatch: AppDispatch = useDispatch()
    useEffect(() => {
        dispatch(checkToken())
    }, [])
    return (
        isAuth
        ? 
            <UserContext.Provider value={user?.role}><Outlet /></UserContext.Provider>
        :
            <Navigate to='/login' replace state={{from: location}} />
    )
}

export default PrivateRoute